@@ -16,7 +16,17 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+In addition, as a special exception, the Free Software Foundation
+gives permission to link the code of its release of Wget with the
+OpenSSL project's "OpenSSL" library (or with modified versions of it
+that use the same license as the "OpenSSL" library), and distribute
+the linked executables.  You must obey the GNU General Public License
+in all respects for all of the code used other than "OpenSSL".  If you
+modify this file, you may extend this exception to your version of the
+file, but you are not obligated to do so.  If you do not wish to do
+so, delete this exception statement from your version.  */
 
 #include <config.h>
 
@@ -42,6 +52,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include <openssl/rand.h>
 
 #include "wget.h"
+#include "utils.h"
 #include "connect.h"
 #include "url.h"
 
@@ -96,11 +107,10 @@ ssl_init_prng (void)
      security will use /dev/random or their own source of randomness
      anyway.  */
 
-  srand (time (NULL));
   while (RAND_status () == 0 && maxrand-- > 0)
     {
-      int rnd = rand ();
-      RAND_seed ((unsigned char *)&rnd, sizeof (rnd));
+      unsigned char rnd = random_number (256);
+      RAND_seed (&rnd, sizeof (rnd));
     }
 
   if (RAND_status () == 0)
@@ -221,9 +231,8 @@ ssl_iread (SSL *con, char *buf, int len)
   do
     {
 #ifdef HAVE_SELECT
-      if (opt.timeout)
+      if (opt.timeout && !SSL_pending (con))
 	{
-	  
 	  do
 	    {
 	      res = select_fd (fd, opt.timeout, 0);
