@@ -15,7 +15,17 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+In addition, as a special exception, the Free Software Foundation
+gives permission to link the code of its release of Wget with the
+OpenSSL project's "OpenSSL" library (or with modified versions of it
+that use the same license as the "OpenSSL" library), and distribute
+the linked executables.  You must obey the GNU General Public License
+in all respects for all of the code used other than "OpenSSL".  If you
+modify this file, you may extend this exception to your version of the
+file, but you are not obligated to do so.  If you do not wish to do
+so, delete this exception statement from your version.  */
 
 #include <config.h>
 
@@ -64,8 +74,8 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
    as much memory as necessary for it to fit.  It need not contain a
    `:', thus you can use it to retrieve, say, HTTP status line.
 
-   The trailing CRLF or LF are stripped from the header, and it is
-   zero-terminated.   #### Is this well-behaved?  */
+   All trailing whitespace is stripped from the header, and it is
+   zero-terminated.  */
 int
 header_get (struct rbuf *rbuf, char **hdr, enum header_get_flags flags)
 {
@@ -101,11 +111,13 @@ header_get (struct rbuf *rbuf, char **hdr, enum header_get_flags flags)
 		  if (next == '\t' || next == ' ')
 		    continue;
 		}
-	      /* The header ends.  */
+
+	      /* Strip trailing whitespace.  (*hdr)[i] is the newline;
+		 decrement I until it points to the last available
+		 whitespace.  */
+	      while (i > 0 && ISSPACE ((*hdr)[i - 1]))
+		--i;
 	      (*hdr)[i] = '\0';
-	      /* Get rid of '\r'.  */
-	      if (i > 0 && (*hdr)[i - 1] == '\r')
-		(*hdr)[i - 1] = '\0';
 	      break;
 	    }
 	}
