@@ -15,7 +15,20 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+In addition, as a special exception, the Free Software Foundation
+gives permission to link the code of its release of Wget with the
+OpenSSL project's "OpenSSL" library (or with modified versions of it
+that use the same license as the "OpenSSL" library), and distribute
+the linked executables.  You must obey the GNU General Public License
+in all respects for all of the code used other than "OpenSSL".  If you
+modify this file, you may extend this exception to your version of the
+file, but you are not obligated to do so.  If you do not wish to do
+so, delete this exception statement from your version.  */
+
+#ifndef HTML_PARSE_H
+#define HTML_PARSE_H
 
 struct attr_pair {
   char *name;			/* attribute name */
@@ -42,3 +55,5 @@ struct taginfo {
 
 void map_html_tags PARAMS ((const char *, int, const char **, const char **,
 			    void (*) (struct taginfo *, void *), void *));
+
+#endif /* HTML_PARSE_H */
