@@ -15,7 +15,17 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+In addition, as a special exception, the Free Software Foundation
+gives permission to link the code of its release of Wget with the
+OpenSSL project's "OpenSSL" library (or with modified versions of it
+that use the same license as the "OpenSSL" library), and distribute
+the linked executables.  You must obey the GNU General Public License
+in all respects for all of the code used other than "OpenSSL".  If you
+modify this file, you may extend this exception to your version of the
+file, but you are not obligated to do so.  If you do not wish to do
+so, delete this exception statement from your version.  */
 
 #include <config.h>
 
@@ -186,15 +196,24 @@ retrieve_tree (const char *start_url)
   uerr_t status = RETROK;
 
   /* The queue of URLs we need to load. */
-  struct url_queue *queue = url_queue_new ();
+  struct url_queue *queue;
 
   /* The URLs we do not wish to enqueue, because they are already in
      the queue, but haven't been downloaded yet.  */
-  struct hash_table *blacklist = make_string_hash_table (0);
+  struct hash_table *blacklist;
 
-  /* We'll need various components of this, so better get it over with
-     now. */
-  struct url *start_url_parsed = url_parse (start_url, NULL);
+  int up_error_code;
+  struct url *start_url_parsed = url_parse (start_url, &up_error_code);
+
+  if (!start_url_parsed)
+    {
+      logprintf (LOG_NOTQUIET, "%s: %s.\n", start_url,
+		 url_error (up_error_code));
+      return URLERROR;
+    }
+
+  queue = url_queue_new ();
+  blacklist = make_string_hash_table (0);
 
   /* Enqueue the starting URL.  Use start_url_parsed->url rather than
      just URL so we enqueue the canonical form of the URL.  */
@@ -438,6 +457,9 @@ download_child_p (const struct urlpos *upos, struct url *parent, int depth,
 
   /* 1. Schemes other than HTTP are normally not recursed into. */
   if (u->scheme != SCHEME_HTTP
+#ifdef HAVE_SSL
+               && u->scheme != SCHEME_HTTPS
+#endif
       && !(u->scheme == SCHEME_FTP && opt.follow_ftp))
     {
       DEBUGP (("Not following non-HTTP schemes.\n"));
@@ -446,7 +468,11 @@ download_child_p (const struct urlpos *upos, struct url *parent, int depth,
 
   /* 2. If it is an absolute link and they are not followed, throw it
      out.  */
-  if (u->scheme == SCHEME_HTTP)
+  if (u->scheme == SCHEME_HTTP
+#ifdef HAVE_SSL
+                 || u->scheme == SCHEME_HTTPS
+#endif
+        )
     if (opt.relative_only && !upos->link_relative_p)
       {
 	DEBUGP (("It doesn't really look like a relative link.\n"));
@@ -534,7 +560,12 @@ download_child_p (const struct urlpos *upos, struct url *parent, int depth,
       }
 
   /* 8. */
-  if (opt.use_robots && u->scheme == SCHEME_HTTP)
+  if (opt.use_robots && (u->scheme == SCHEME_HTTP
+#ifdef HAVE_SSL
+                         || u->scheme == SCHEME_HTTPS
+#endif
+                         )
+        )
     {
       struct robot_specs *specs = res_get_specs (u->host, u->port);
       if (!specs)
