@@ -15,7 +15,17 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+In addition, as a special exception, the Free Software Foundation
+gives permission to link the code of its release of Wget with the
+OpenSSL project's "OpenSSL" library (or with modified versions of it
+that use the same license as the "OpenSSL" library), and distribute
+the linked executables.  You must obey the GNU General Public License
+in all respects for all of the code used other than "OpenSSL".  If you
+modify this file, you may extend this exception to your version of the
+file, but you are not obligated to do so.  If you do not wish to do
+so, delete this exception statement from your version.  */
 
 #include <config.h>
 
@@ -528,6 +538,11 @@ parse_uname (const char *str, int len, char **user, char **passwd)
   memcpy (*user, str, len);
   (*user)[len] = '\0';
 
+  if (*user)
+    decode_string (*user);
+  if (*passwd)
+    decode_string (*passwd);
+
   return 1;
 }
 
@@ -1209,7 +1224,12 @@ mkstruct (const struct url *u)
       if (u->port != scheme_default_port (u->scheme))
 	{
 	  int len = strlen (dirpref);
+#if WINDOWS || __CYGWIN__
+	  /* Use '_' instead of ':' here for Windows. */
+	  dirpref[len] = '_';
+#else
 	  dirpref[len] = ':';
+#endif
 	  number_to_string (dirpref + len + 1, u->port);
 	}
     }
@@ -1248,7 +1268,12 @@ mkstruct (const struct url *u)
   sprintf (res, "%s%s%s", dir, *dir ? "/" : "", file);
   if (query)
     {
+#if WINDOWS || __CYGWIN__
+      /* Temporary fix.  Use "@" instead of "?" here for Windows. */
+      strcat (res, "@");
+#else
       strcat (res, "?");
+#endif
       strcat (res, query);
     }
   if (dir != dir_preencoding)
@@ -1285,7 +1310,12 @@ compose_file_name (char *base, char *query)
 
   if (query && to - result < sizeof (result))
     {
+#if WINDOWS || __CYGWIN__
+      /* Temporary fix.  Use '@' instead of '?' here for Windows. */
+      *to++ = '@';
+#else
       *to++ = '?';
+#endif
 
       /* Copy QUERY to RESULT and encode all '/' characters. */
       from = query;
@@ -1575,6 +1605,35 @@ uri_merge_1 (const char *base, const char *link, int linklength, int no_scheme)
 	  memcpy (constr + baselength, link, linklength);
 	  constr[baselength + linklength] = '\0';
 	}
+      else if (linklength > 1 && *link == '/' && *(link + 1) == '/')
+	{
+	  /* LINK begins with "//" and so is a net path: we need to
+	     replace everything after (and including) the double slash
+	     with LINK.
+
+	     So, if BASE is "http://oldhost/whatever/foo/bar", and LINK
+	     is "//newhost/qux/xyzzy", our result should be
+	     "http://newhost/qux/xyzzy".  */
+	  int span;
+	  const char *slash;
+	  const char *start_insert;
+	  /* Look for first slash. */
+	  slash = memchr (base, '/', end - base);
+	  /* If found slash and it is a double slash, then replace
+	     from this point,
+	     else default to replacing from the beginning.  */
+	  if (slash && *(slash + 1) == '/')
+	    start_insert = slash;
+	  else
+	    start_insert = base;
+
+	  span = start_insert - base;
+	  constr = (char *)xmalloc (span + linklength + 1);
+	  if (span)
+	    memcpy (constr, base, span);
+	  memcpy (constr + span, link, linklength);
+	  constr[span + linklength] = '\0';
+	}
       else if (*link == '/')
 	{
 	  /* LINK is an absolute path: we need to replace everything
