@@ -15,7 +15,17 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+In addition, as a special exception, the Free Software Foundation
+gives permission to link the code of its release of Wget with the
+OpenSSL project's "OpenSSL" library (or with modified versions of it
+that use the same license as the "OpenSSL" library), and distribute
+the linked executables.  You must obey the GNU General Public License
+in all respects for all of the code used other than "OpenSSL".  If you
+modify this file, you may extend this exception to your version of the
+file, but you are not obligated to do so.  If you do not wish to do
+so, delete this exception statement from your version.  */
 
 /* This file contains some declarations that don't fit anywhere else.
    It also contains some useful includes, like the obnoxious TIME_H
@@ -251,8 +261,9 @@ char *xstrdup_debug PARAMS ((const char *, const char *, int));
 	XREALLOC_ARRAY (basevar, type, do_realloc_newsize);			\
       else									\
 	{									\
-	  void *drfa_new_basevar = xmalloc (do_realloc_newsize);		\
-	  memcpy (drfa_new_basevar, basevar, (sizevar));			\
+	  void *drfa_new_basevar =						\
+		xmalloc (do_realloc_newsize * sizeof (type));			\
+	  memcpy (drfa_new_basevar, basevar, (sizevar) * sizeof (type));	\
 	  (basevar) = drfa_new_basevar;						\
 	  allocap = 0;								\
 	}									\
