@@ -16,6 +16,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+# In addition, as a special exception, the Free Software Foundation
+# gives permission to link the code of its release of Wget with the
+# OpenSSL project's "OpenSSL" library (or with modified versions of it
+# that use the same license as the "OpenSSL" library), and distribute
+# the linked executables.  You must obey the GNU General Public License
+# in all respects for all of the code used other than "OpenSSL".  If you
+# modify this file, you may extend this exception to your version of the
+# file, but you are not obligated to do so.  If you do not wish to do
+# so, delete this exception statement from your version.
+
 
 # This script is a very lame hack to remove local files, until the
 # time when Wget proper will have this functionality.
@@ -31,10 +41,8 @@ if (@ARGV && ($ARGV[0] eq '-v')) {
     $verbose = 1;
 }
 
-defined($dirs[0] = shift) || ($dirs[0] = '.');
-while (defined($_ = shift)) {
-    @dirs = (@dirs, $_);
-}
+(@dirs = @ARGV) || push (@dirs,'.');
+
 
 foreach $_ (@dirs) {
     &procdir($_);
@@ -44,7 +52,7 @@ foreach $_ (@dirs) {
 
 sub procdir
 {
-    local($dir = $_[0]);
+    local $dir = shift;
     local(@lcfiles, @lcdirs, %files, @fl);
 
     print STDERR "Processing directory '$dir':\n" if $verbose;
@@ -55,17 +63,17 @@ sub procdir
     # Read local files and directories.
     foreach $_ (readdir(DH)) {
         /^(\.listing|\.\.?)$/ && next;
-        if (-d "$dir/$_" || -l "$dir/$_") {
-            @lcdirs = (@lcdirs, $_);
+        lstat ("$dir/$_");
+        if (-d _) {
+            push (@lcdirs, $_);
         }
         else {
-            @lcfiles = (@lcfiles, $_);
+            push (@lcfiles, $_);
         }
     }
     closedir(DH);
     # Parse .listing
     if (open(FD, "<$dir/.listing")) {
-        @files = ();
         while (<FD>)
         {
             # Weed out the line beginning with 'total'
